@@ -35,7 +35,9 @@ class RecurrenceWidget(TextAreaWidget):
     def get_start_field(self):
         if self.mode == 'display':
             return self.id + '-start'
-        return self.form.widgets[self.start_field].js_field
+        if hasattr(self.form.widgets[self.start_field], 'js_field'):
+            return self.form.widgets[self.start_field].js_field
+        return self.form.widgets[self.start_field].id
 
     def get_start_date(self):
         start = self.form.fields[self.start_field].field.get(self.context)
@@ -43,7 +45,9 @@ class RecurrenceWidget(TextAreaWidget):
 
     def first_day(self):
         """ First day of the Week. 0..Sunday, 6..Saturday.
-        You can overwrite this default value via widget configuration.
+
+        .. Note::
+            This value is likely to be overwritten by the widget configuration.
         """
         calendar = self.request.locale.dates.calendars[u'gregorian']
         return calendar.week.get('firstDay', 0)
@@ -52,14 +56,14 @@ class RecurrenceWidget(TextAreaWidget):
         portal = getToolByName(getSite(), 'portal_url').getPortalObject()
         ajax_url = portal.absolute_url() + '/@@json_recurrence'
         params = dict(
-            lang=self.request.LANGUAGE,
-            readOnly=self.read_only(),
-            startField=self.get_start_field(),
+            ajaxContentType='application/x-www-form-urlencoded; charset=UTF-8',
+            ajaxURL=ajax_url,
             firstDay=self.first_day(),
             hasRepeatForeverButton=self.show_repeat_forever,
-            ajaxURL=ajax_url,
-            ajaxContentType='application/x-www-form-urlencoded; charset=UTF-8',
-            ributtonExtraClass='allowMultiSubmit'
+            lang=self.request.LANGUAGE,
+            readOnly=self.read_only(),
+            ributtonExtraClass='allowMultiSubmit',
+            startField=self.get_start_field(),
         )
         return params
 
